@@ -9,7 +9,7 @@ use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use namespace::autoclean;
 
-our $VERSION = '0.922';
+our $VERSION = '0.93';
 
 has sqitch => (
     is       => 'ro',
@@ -98,7 +98,7 @@ sub deploy {
         defined $to ? __x(
             'Deploying changes through {target} to {destination}',
             destination => $self->destination,
-            target      => $to
+            target      => $plan->change_at($to_index)->format_name_with_tags
         ) : __x(
             'Deploying changes to {destination}',
             destination => $self->destination,
@@ -134,9 +134,9 @@ sub revert {
         );
 
         $sqitch->info(__x(
-            'Reverting from {destination} to {target}',
+            'Reverting changes to {target} from {destination}',
+            target      => $change->format_name_with_tags,
             destination => $self->destination,
-            target      => $to
         ));
     } else {
         @change_ids = $self->deployed_change_ids or hurl {
@@ -349,9 +349,15 @@ sub revert_change {
 sub begin_work  { shift }
 sub finish_work { shift }
 
+sub earliest_change {
+    my $self = shift;
+    my $change_id = $self->earliest_change_id(@_) // return undef;
+    return $self->sqitch->plan->get( $change_id );
+}
+
 sub latest_change {
     my $self = shift;
-    my $change_id = $self->latest_change_id // return undef;
+    my $change_id = $self->latest_change_id(@_) // return undef;
     return $self->sqitch->plan->get( $change_id );
 }
 
@@ -410,6 +416,11 @@ sub change_id_for_depend {
     hurl "$class has not implemented change_id_for_depend()";
 }
 
+sub earliest_change_id {
+    my $class = ref $_[0] || $_[0];
+    hurl "$class has not implemented earliest_change_id()";
+}
+
 sub latest_change_id {
     my $class = ref $_[0] || $_[0];
     hurl "$class has not implemented latest_change_id()";
@@ -635,12 +646,23 @@ revert an individual change.
 Convenience method that dispatches to C<is_deployed_tag()> or
 C<is_deployed_change()> as appropriate to its argument.
 
+=head3 C<earliest_change>
+
+  my $change = $engine->earliest_change;
+
+Returns the L<App::Sqitch::Plan::Change> object representing the earliest
+applied change. With the optional C<$offset> argument, the returned change
+will be the offset number of changes following the earliest change.
+
+
 =head3 C<latest_change>
 
   my $change = $engine->latest_change;
+  my $change = $engine->latest_change($offset);
 
-Returns the L<App::Sqitch::Plan::Change> object representing the most recently
-applied change.
+Returns the L<App::Sqitch::Plan::Change> object representing the latest
+applied change. With the optional C<$offset> argument, the returned change
+will be the offset number of changes before the latest change.
 
 =head2 Abstract Instance Methods
 
@@ -758,11 +780,22 @@ of the change failed.
 Should write to and/or remove from the database metadata and history the
 records necessary to indicate that the change has been reverted.
 
+=head3 C<earliest_change_id>
+
+  my $change_id = $engine->earliest_change_id($offset);
+
+Returns the ID of the earliest applied change from the current project. With
+the optional C<$offset> argument, the ID of the change the offset number of
+changes following the earliest change will be returned.
+
 =head3 C<latest_change_id>
 
   my $change_id = $engine->latest_change_id;
+  my $change_id = $engine->latest_change_id($offset);
 
-Returns the ID of the most recently applied change from the current project.
+Returns the ID of the latest applied change from the current project.
+With the optional C<$offset> argument, the ID of the change the offset
+number of changes before the latest change will be returned.
 
 =head3 C<deployed_change_ids>
 
