@@ -17,23 +17,24 @@ use namespace::autoclean;
 use Moose;
 use constant SYNTAX_VERSION => '1.0.0-b2';
 
-our $VERSION = '0.922';
+our $VERSION = '0.93';
 
 # Like [:punct:], but excluding _. Copied from perlrecharclass.
 my $punct = q{-!"#$%&'()*+,./:;<=>?@[\\]^`{|}~};
-my $refpunct = q{~^/=%};
-my $name_re = qr/
+my $name_re = qr{
     (?![$punct])                   # first character isn't punctuation
     (?:                            # start non-capturing group, repeated once or more ...
        (?!                         #     negative look ahead for...
-           [$refpunct]             #         symbolic reference punctuation
+           [~/=%^]                 #         symbolic reference punctuation
            [[:digit:]]+            #         digits
            (?:$|[[:blank:]])       #         eol or blank
        )                           #     ...
        [^[:blank:]:@#]             #     match a valid character
     )+                             # ... end non-capturing group
     (?<![$punct])\b                # last character isn't punctuation
-/x;
+}x;
+
+my %reserved = map { $_ => undef } qw(ROOT HEAD FIRST LAST);
 
 sub name_regex { $name_re }
 
@@ -308,7 +309,7 @@ sub _parse {
         $raise_syntax_error->(__x(
             '"{name}" is a reserved name',
             name => ($type eq 'tag' ? '@' : '') . $params{name},
-        )) if $params{name} eq 'HEAD' || $params{name} eq 'ROOT';
+        )) if exists $reserved{ $params{name} };
 
         # It must not look like a SHA1 hash.
         $raise_syntax_error->(__x(
@@ -767,7 +768,7 @@ sub _is_valid {
     hurl plan => __x(
         '"{name}" is a reserved name',
         name => $name
-    ) if $name eq 'HEAD' || $name eq 'ROOT';
+    ) if exists $reserved{$name};
     hurl plan => __x(
         '"{name}" is invalid because it could be confused with a SHA1 ID',
         name => $name,
